Changelog
=========


0.4.2 (2017-07-01)
-----------------------------

Fix
~~~
- Handle composite pks when one pk is None. [Serkan Hosca]


0.4.1 (2017-07-01)
------------------

Fix
~~~
- Nested model primary key field generation. [Serkan Hosca]

Other
~~~~~
- Fix readme. [Serkan Hosca]


0.4.0 (2017-06-28)
------------------

Fix
~~~
- Field label generation. [Serkan Hosca]

Refactor
~~~~~~~~
- Lots of minor pylint and pycharm linter fixes. [Serkan Hosca]

Other
~~~~~
- Update gitchangelog.rc. [Serkan Hosca]


0.3.5 (2017-06-18)
------------------

Fix
~~~
- Increase coverage. [Serkan Hosca]

Refactor
~~~~~~~~
- Dedup update attribute logic. [Serkan Hosca]
- Run pre-commit as part of build. [Serkan Hosca]


0.3.4 (2017-06-14)
------------------

Refactor
~~~~~~~~
- Better route name handling and nullable boolean field tests. [Serkan
  Hosca]

Documentation
~~~~~~~~~~~~~
- Update gitchangelog config. [Serkan Hosca]


0.3.3 (2017-06-13)
------------------

Fix
~~~
- Add pipenv for setup. [Serkan Hosca]

Documentation
~~~~~~~~~~~~~
- Fix versioning. [Serkan Hosca]


0.3.2 (2017-06-13)
------------------

Fix
~~~
- Stop passing around is_nested and fix autoincrement value check.
  [Serkan Hosca]


0.3.1 (2017-06-11)
------------------
- Delete tests and coverall config. [Serkan Hosca]


0.3.0 (2017-06-11)
------------------

Fix
~~~
- Nested list serializer flags. [Serkan Hosca]
- Generic destroy with sqlalchemy. [Serkan Hosca]
- Handle autoincrement and nested update with existing instance. [Serkan
  Hosca]

Refactor
~~~~~~~~
- Model_info changes and added docstrings. [Serkan Hosca]

Other
~~~~~
- Initial doc setup. [Serkan Hosca]


0.2.1 (2017-06-10)
------------------
- Initial doc setup. [Serkan Hosca]


0.2.0 (2017-06-10)
------------------
- Refactor field mapping and object fetching and more tests. [Serkan
  Hosca]


0.1.4 (2017-06-09)
------------------
- Respect allow_null. [Serkan Hosca]


0.1.2 (2017-06-08)
------------------
- Mark all columns read only when allow_nested_updates is false. [Serkan
  Hosca]


0.1.1 (2017-06-07)
------------------
- Fix composite serializer. [Serkan Hosca]


0.1.0 (2017-06-06)
------------------
- Add more tests and generic api fixes. [Serkan Hosca]


0.0.6 (2017-06-05)
------------------
- Add missing dep and add pypi badge. [Serkan Hosca]
- Add more tests for composite routes. [Serkan Hosca]


0.0.5 (2017-06-05)
------------------
- Add route tests. [Serkan Hosca]


0.0.4 (2017-06-05)
------------------
- Add pre-commit. [Serkan Hosca]
- Move GenericAPIView. [Serkan Hosca]
- Fix Readme. [Serkan Hosca]


0.0.2 (2017-06-02)
------------------
- Fix setup publish and make clean. [Serkan Hosca]
- Added viewsets and version bump. [Serkan Hosca]
- Update readme. [Serkan Hosca]


0.0.1 (2017-06-02)
------------------
- Fix readme. [Serkan Hosca]
- Added initial readme. [Serkan Hosca]
- Add travis. [Serkan Hosca]
- Initial commit. [Serkan Hosca]


